@@ -1,5 +1,4 @@
 # Copyright (C) 2013 Julian Metzler
 # See the LICENSE file for the full license.
 
-from tweetpony.api import *
-from tweetpony.api import *
\ No newline at end of file
+from .api import *
